@@ -4,7 +4,7 @@
 import mcpi
 from mcpi.vec3 import Vec3
 
-from .scene import Scene
+from .world import World
 from .thing import Thing
 
 
@@ -16,6 +16,7 @@ class Fence(Thing):
     fence_space = 5
     """ Space between the fence and the thing fenced """
     thick = 1
+    height = None
     thing = None
 
     def build(self):
@@ -36,17 +37,19 @@ class Fence(Thing):
 
         end_x = self.thing.end_position.x + self.fence_space + self.thick
         end_y = self.thing.end_position.y
+        if self.height:
+            end_y = self.thing.position.y + (self.height - 1)
         end_z = self.thing.end_position.z + self.fence_space + self.thick
 
         self._end_position = Vec3(end_x, end_y, end_z)
 
-        Scene.server.setBlocks(
+        World.server.setBlocks(
             init_x, init_y, init_z,
             end_x, end_y, end_z,
             self.block)
 
         # Fill the prism with air to became a rectangular wall
-        Scene.server.setBlocks(
+        World.server.setBlocks(
             init_x + self.thick, init_y, init_z + self.thick,
             end_x - self.thick,
             end_y,
